@@ -3,7 +3,7 @@ package Ryu::Async;
 use strict;
 use warnings;
 
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 
 =head1 NAME
 
@@ -69,6 +69,10 @@ use Variable::Disposition qw(retain_future);
 use Log::Any qw($log);
 use Syntax::Keyword::Try;
 
+use Ryu::Source;
+
+use Ryu::Async::Process;
+
 =head1 METHODS
 
 =cut
@@ -246,6 +250,28 @@ sub timer {
     $src
 }
 
+=head2 run
+
+Creates an L<IO::Async::Process>.
+
+=cut
+
+sub run {
+    my ($self, $code, %args) = @_;
+    if(ref($code) eq 'ARRAY') {
+        # Fork and exec
+        $args{command} = $code;
+    } elsif(ref($code) eq 'CODE') {
+        $args{code} = $code;
+    }
+    $self->add_child(
+        my $process = Ryu::Async::Process->new(
+            process => IO::Async::Process->new(%args)
+        )
+    );
+    $process;
+}
+
 =head2 source
 
 Returns a new L<Ryu::Source> instance.
@@ -357,7 +383,7 @@ sub udp_server {
                 $src->emit(
                     Ryu::Async::Packet->new(
                         payload => $msg, 
-                        from => $addr
+                        from    => $addr
                     )
                 )
             },
@@ -397,6 +423,27 @@ sub timeout {
 
 Returns a new L<Ryu::Sink>.
 
+The label will default to the calling package/class and method,
+with some truncation rules:
+
+=over 4
+
+=item * A C<Net::Async::> prefix will be replaced by C<Na>.
+
+=item * A C<Web::Async::> prefix will be replaced by C<Wa>.
+
+=item * A C<IO::Async::> prefix will be replaced by C<Ia>.
+
+=item * A C<Tickit::Async::> prefix will be replaced by C<Ta>.
+
+=item * A C<Tickit::Widget::> prefix will be replaced by C<TW>.
+
+=back
+
+This list of truncations is subject to change, so please don't
+rely on any of these in string matches or similar - better to set
+your own label if you need consistency.
+
 =cut
 
 sub sink {
@@ -407,6 +454,7 @@ sub sink {
         $label =~ s/^IO::Async::/Ia/g;
         $label =~ s/^Web::Async::/Wa/g;
         $label =~ s/^Tickit::Async::/Ta/g;
+        $label =~ s/^Tickit::Widget::/TW/g;
         $label =~ s/::([^:]*)$/->$1/;
         $label
     };
